/* Last modified: August 19, 2015

*--------------------*
*    INPUT FILES     *
*--------------------*

Packages needed: estout - available from within Stata via "ssc install estout" or at http://repec.org/bocode/e/estout/esttab.html
	         xtabond2 - available from within Stata via"ssc install xtabond2" 
		 (Note: the xtabond2 command as we use it may not function properly on versions of Stata older than Stata 13)
		 ivreg2 - available from within Stata via "ssc install ivreg2"
Files needed: 

bds.dta - a cleaned version of the Business Dyanamics Statistics, linked to State minimum wage data and other covariates

*/

*--------------------*
* Set these:

global datadir "/home/jeremy/data/jhr/data_code" // Location of data and code
global savedir "/home/jeremy/data/jhr/tex" // Location of figures and tables folders

*--------------------*

clear all
set more off
cd "$datadir"

*--------------------*
*   DYNAMIC PANEL    *
*--------------------*

use bds , clear

gen reg_y = censusreg * 10000 + year // For factor variable to use with ivreg2

qui xtabond2 lemp L.lemp L(0/1).lnmin i.year#i.censusreg lpopall share1559 lrgspcap, gmm(lnmin) iv(L.lemp i.year#i.censusreg lpopall share1559 lrgspcap) nolevel robust
eststo dp1

qui nlcom (_b[L.lnmin] + _b[lnmin]) / (1 - _b[L.lemp]), post
eststo nlcom1

qui xtabond2 lemp L.lemp L(0/3).lnmin i.year#i.censusreg lpopall share1559 lrgspcap, gmm(lnmin) iv(L.lemp i.year#i.censusreg lpopall share1559 lrgspcap) nolevel robust
eststo dp2

qui nlcom (_b[L.lnmin] + _b[L2.lnmin] + _b[L3.lnmin] + _b[lnmin]) / (1 - _b[L.lemp]), post
eststo nlcom2

qui xi: ivreg2 D.lemp (LD.lemp = L(2/6)D.lnmin) L(0/1)D.lnmin D.(lpopall share1559 lrgspcap) i.reg_y, cluster(statefips)
eststo dp3

qui nlcom (_b[D1.lnmin] + _b[LD.lnmin]) / (1 - _b[LD.lemp]), post
eststo nlcom3
 
qui xi: ivreg2 D.lemp (LD.lemp = L(4/8)D.lnmin) L(0/3)D.lnmin D.(lpopall share1559 lrgspcap) i.reg_y, cluster(statefips)
eststo dp4

qui nlcom (_b[D1.lnmin] + _b[LD.lnmin] + _b[L2D.lnmin] + _b[L3D.lnmin])/(1-_b[LD.lemp]), post
eststo nlcom4

#delimit ;
esttab dp1 dp2 dp3 dp4 using "$savedir/tables/table_dynamicpanel.csv", replace
b(4) se(4) label star(* 0.1 ** 0.05 *** 0.01) keep(*lnmin* *lemp*) nonotes nogaps nomtitles noobs 
coeflabels(L.lemp "1st lag of employment" LD.lemp "1st lag of employment"
lnmin "Log-MW" D.lnmin "Log-MW" L.lnmin "1st lag of log-MW" L2.lnmin "2nd lag of log-MW"
L3.lnmin "3rd lag of log-MW" LD.lnmin "1st lag of log-MW" L2D.lnmin "2nd lag of log-MW"
L3D.lnmin "3rd lag of log-MW"
)
order(lnmin L.lnmin L2.lnmin L3.lnmin L.lemp D.lnmin LD.lnmin L2D.lnmin L3D.lnmin LD.lemp)
;
#delimit cr

#delimit ;
esttab nlcom1 nlcom2 nlcom3 nlcom4 using "$savedir/tables/table_dynamicpanel.csv", append
b(4) se(4) label star(* 0.1 ** 0.05 *** 0.01) nonotes nogaps nomtitles nonum
coeflabels(_nl_1  "Sum of MW effects")
;
#delimit cr
