/* Last modified: August 19, 2015

*--------------------*
*    INPUT FILES     *
*--------------------*

Packages needed: estout - available from within Stata by typing "ssc install estout" or at http://repec.org/bocode/e/estout/esttab.html

Files needed: 

bds.dta - a cleaned version of the Business Dyanamics Statistics, linked to State minimum wage data and other covariates

qcew.dta - a cleaned version of the Quarterly Census of Employment and Wages, linked to State minimum wage data and other covariates

qwi.dta - a cleaned version of the Quarterly Worforce Indicators, linked to State minimum wage data and other covariates

*/

*--------------------*
* Set these:

global datadir "/home/jeremy/data/jhr/data_code" // Location of data and code
global savedir "/home/jeremy/data/jhr/tex" // Location of figures and tables folders

*--------------------*

clear all
set more off
set matsize 4000
cd "$datadir"

*--------------------*
* SUMMARY STATISTICS *
*--------------------*

clear all
set more off

* BDS:

use bds , clear

sort statefips year
xtset statefips year
gen jg = D.emp
gen jgl = D.lemp

foreach var in emp jg popall {
replace `var'=`var'/1000
}

quietly estpost summarize mw realmw emp jg jgl popall share1559 rgspcap , detail
eststo sumstats_bds

* QCEW:

use qcew , clear
keep if industry == 10 // All ages in all industries in all sectors and ownership

sort statefips quarterly
xtset statefips quarterly
gen jg = D.emp
gen jgl = D.lemp

foreach var in emp jg popall {
replace `var'=`var'/1000
}

gen jc = . // Placeholder
gen jd = . // Placeholder

quietly estpost summarize mw realmw emp jg jgl popall share1559 rgspcap , detail
eststo sumstats_qcew

* QWI:

use qwi , clear
keep if industry == 10 & agegrp == 0 // All ages in all industries in all sectors and ownership

sort statefips quarterly
xtset statefips quarterly
gen jg = D.emp
gen jgl = D.lemp

foreach var in emp jg popall {
replace `var'=`var'/1000
}

quietly estpost summarize mw realmw emp jg jgl popall share1559 rgspcap , detail
eststo sumstats_qwi

#delimit ;
esttab sumstats_bds sumstats_qcew sumstats_qwi using "$savedir/tables/table_sumstats_appendix.csv" , replace 
cells(`"mean(fmt(a2)) sd(fmt(a3)) p50(fmt(a2))"') 
label collabels("Mean" "Std. Dev." "Median") 
coeflabels(mw "State minimum wage (\$)" realmw "State minimum wage (\$real)" 
jg "Job growth (thousands)" jgl "Job growth (log)" emp "Jobs (thousands)" 
popall "Population (thousands)" share1559 "Share aged 15-59" rgspcap "GSP/capita (\$real)")
nomtitles nonum
;
#delimit cr

*--------------------*
*  CLASSIC RESULTS   *
*--------------------*

* QCEW

use qcew , clear
keep if industry == 10 // All ages in all industries in all sectors and ownership
sort state quarterly
xtset state quarterly
fvset base 1 state // Setting some technical factor-variable settings
fvset base 1 quarterly // Setting some technical factor-variable settings

estimates clear

qui xtreg lemp lnmin i.quarterly , fe robust cluster(state)
eststo col1
estadd local timefe "National"
estadd local timecontrols "No"
estadd local timetrend "No"

qui xtreg lemp lnmin i.quarterly lpopall share1559 lrgspcap , fe robust cluster(state)
eststo col2
estadd local timefe "National"
estadd local timecontrols "Yes"
estadd local timetrend "No"

qui xtreg lemp lnmin i.quarterly#i.censusreg lpopall share1559 lrgspcap , fe robust cluster(state)
eststo col3
estadd local timefe "Regional"
estadd local timecontrols "Yes"
estadd local timetrend "No"

qui xtreg lemp F(0/1).lnmin i.quarterly#i.censusreg lpopall share1559 lrgspcap , fe robust cluster(state)
eststo col4
estadd local timefe "Regional"
estadd local timecontrols "Yes"
estadd local timetrend "No"

qui xtreg lemp F(0/2).lnmin i.quarterly#i.censusreg lpopall share1559 lrgspcap , fe robust cluster(state)
eststo col5
estadd local timefe "Regional"
estadd local timecontrols "Yes"
estadd local timetrend "No"

qui xtreg lemp lnmin i.quarterly#i.censusreg lpopall share1559 lrgspcap i.state#c.quarterly, fe robust cluster(state)
eststo col6
estadd local timefe "Regional"
estadd local timecontrols "Yes"
estadd local timetrend "Yes"

#delimit ;
esttab col1 col2 col3 col4 col5 col6 using "$savedir/tables/table_classic_QCEW_QWI.tex", replace fragment
b(4) se(4) label star(* 0.1 ** 0.05 *** 0.01) keep(*lnmin*) nonotes nogaps nomtitles
coeflabels(lnmin "\textbf{Panel A: QCEW} \\ Log-MW" F.lnmin "1st lead of log-MW" F2.lnmin "2nd lead of log-MW" )
;
#delimit cr


* QWI:

use qwi , clear
keep if industry == 10 & agegrp == 0 // All ages in all industries in all sectors and ownership

sort state quarterly
xtset state quarterly
fvset base 1 state // Setting some technical factor-variable settings
fvset base 1 quarterly // Setting some technical factor-variable settings

estimates clear

qui xtreg lemp lnmin i.quarterly , fe robust cluster(state)
eststo col1
estadd local timefe "National"
estadd local timecontrols "No"
estadd local timetrend "No"

qui xtreg lemp lnmin i.quarterly lpopall share1559 lrgspcap , fe robust cluster(state)
eststo col2
estadd local timefe "National"
estadd local timecontrols "Yes"
estadd local timetrend "No"

qui xtreg lemp lnmin i.quarterly#i.censusreg lpopall share1559 lrgspcap , fe robust cluster(state)
eststo col3
estadd local timefe "Regional"
estadd local timecontrols "Yes"
estadd local timetrend "No"

qui xtreg lemp F(0/1).lnmin i.quarterly#i.censusreg lpopall share1559 lrgspcap , fe robust cluster(state)
eststo col4
estadd local timefe "Regional"
estadd local timecontrols "Yes"
estadd local timetrend "No"

qui xtreg lemp F(0/2).lnmin i.quarterly#i.censusreg lpopall share1559 lrgspcap , fe robust cluster(state)
eststo col5
estadd local timefe "Regional"
estadd local timecontrols "Yes"
estadd local timetrend "No"

qui xtreg lemp lnmin i.quarterly#i.censusreg lpopall share1559 lrgspcap i.state#c.quarterly, fe robust cluster(state)
eststo col6
estadd local timefe "Regional"
estadd local timecontrols "Yes"
estadd local timetrend "Yes"

#delimit ;
esttab col1 col2 col3 col4 col5 col6 using "$savedir/tables/table_classic_QCEW_QWI.tex", append fragment
b(4) se(4) label star(* 0.1 ** 0.05 *** 0.01) keep(*lnmin*) nonotes nogaps nomtitles nonum
coeflabels(lnmin "\textbf{Panel B: QWI} \\ Log-MW" F.lnmin "1st lead of log-MW" F2.lnmin "2nd lead of log-MW" )
scalars("timefe Time FE" "timecontrols [-0.2cm]Time-varying controls" "timetrend [-0.2cm]Jurisdiction time trends")
;
#delimit cr

*--------------------*
*  LONG DIFFERENCES  *
*--------------------*

* QCEW

use qcew , clear
keep if industry == 10 // All ages in all industries in all sectors and ownership
sort state quarterly
xtset state quarterly
fvset base 1 state // Setting some technical factor-variable settings
fvset base 1 quarterly // Setting some technical factor-variable settings

estimates clear

forv i = 1/8 {
local j = `i' * 4

gen zzzlnmin = S`j'.lnmin // For better table format purposes

* Without trends:
qui reg S`j'.lemp zzzlnmin S`j'.lpopall S`j'.share1559 S`j'.lrgspcap i.year#i.censusreg , robust cluster(state)
estimates store col`i'

* With trends:
qui reg S`j'.lemp zzzlnmin i.state#c.year S`j'.lpopall S`j'.share1559 S`j'.lrgspcap i.year#i.censusreg , robust cluster(state)
estimates store col`i'b

drop zzzlnmin
}

#delimit ;
esttab col1 col2 col3 col4 col5 col6 col7 col8 using "$savedir/tables/table_longdiff_QCEW_QWI.tex", replace fragment
b(4) se(4) label star(* 0.1 ** 0.05 *** 0.01) keep(*lnmin*) nonotes nogaps noobs
coeflabels(zzzlnmin "\multicolumn{3}{l}{\textbf{Panel A: QCEW without trends}} \\ Long difference in log-MW")
mtitles("4" "8" "12" "16" "20" "24" "28" "32" )
;
#delimit cr

#delimit ;
esttab col1b col2b col3b col4b col5b col6b col7b col8b using "$savedir/tables/table_longdiff_QCEW_QWI.tex", append fragment
b(4) se(4) label star(* 0.1 ** 0.05 *** 0.01) keep(*lnmin*) nonotes nogaps nomtitles nonum
coeflabels(zzzlnmin "\multicolumn{3}{l}{\textbf{Panel B: QCEW with trends}} \\ Long difference in log-MW")
;
#delimit cr

* QWI

use qwi , clear
keep if industry == 10 & agegrp == 0 // All ages in all industries in all sectors and ownership

sort state quarterly
xtset state quarterly
fvset base 1 state // Setting some technical factor-variable settings
fvset base 1 quarterly // Setting some technical factor-variable settings

estimates clear

forv i = 1/8 {
local j = `i' * 4

gen zzzlnmin = S`j'.lnmin // For better table format purposes

* Without trends:
qui reg S`j'.lemp zzzlnmin S`j'.lpopall S`j'.share1559 S`j'.lrgspcap i.year#i.censusreg , robust cluster(state)
estimates store col`i'

* With trends:
qui reg S`j'.lemp zzzlnmin i.state#c.year S`j'.lpopall S`j'.share1559 S`j'.lrgspcap i.year#i.censusreg , robust cluster(state)
estimates store col`i'b

drop zzzlnmin
}

#delimit ;
esttab col1 col2 col3 col4 col5 col6 col7 col8 using "$savedir/tables/table_longdiff_QCEW_QWI.tex", append fragment
b(4) se(4) label star(* 0.1 ** 0.05 *** 0.01) keep(*lnmin*) nonotes nogaps noobs nomtitles nonum
coeflabels(zzzlnmin "\multicolumn{3}{l}{\textbf{Panel C: QWI without trends}} \\ Long difference in log-MW")
;
#delimit cr

#delimit ;
esttab col1b col2b col3b col4b col5b col6b col7b col8b using "$savedir/tables/table_longdiff_QCEW_QWI.tex", append fragment
b(4) se(4) label star(* 0.1 ** 0.05 *** 0.01) keep(*lnmin*) nonotes nogaps nomtitles nonum
coeflabels(zzzlnmin "\multicolumn{3}{l}{\textbf{Panel D: QWI with trends}} \\ Long difference in log-MW")
;
#delimit cr

*--------------------*
*  DISTRIBUTED LAG   *
*--------------------*

* QCEW

use qcew , clear
keep if industry == 10 // All ages in all industries in all sectors and ownership
sort state quarterly
xtset state quarterly
fvset base 1 state // Setting some technical factor-variable settings
fvset base 1 quarterly // Setting some technical factor-variable settings

estimates clear

qui reg D.lemp DL(0/15).lnmin i.quarterly#i.censusreg S4.lpopall S4.share1559 S4.lrgspcap , robust cluster(state)
estimates store col1

qui lincomest D.lnmin + DL.lnmin + DL2.lnmin + DL3.lnmin + DL4.lnmin + DL5.lnmin + DL6.lnmin + DL7.lnmin + DL8.lnmin + ///
DL9.lnmin + DL10.lnmin + DL11.lnmin + DL12.lnmin + DL13.lnmin + DL14.lnmin + DL15.lnmin
estimates store lincom1

qui reg D.lemp DL(0/15).lnmin DF(1/4).lnmin i.quarterly#i.censusreg S4.lpopall S4.share1559 S4.lrgspcap , robust cluster(state)
estimates store col2

qui lincomest D.lnmin + DL.lnmin + DL2.lnmin + DL3.lnmin + DL4.lnmin + DL5.lnmin + DL6.lnmin + DL7.lnmin + DL8.lnmin + ///
DL9.lnmin + DL10.lnmin + DL11.lnmin + DL12.lnmin + DL13.lnmin + DL14.lnmin + DL15.lnmin
estimates store lincom2

qui reg D.lemp DL(0/15).lnmin DF(1/4).lnmin i.quarterly#i.censusreg S4.lpopall S4.share1559 S4.lrgspcap , robust cluster(state)
qui lincomest DF.lnmin + DF2.lnmin + DF3.lnmin + DF4.lnmin
estimates store lincom2_2


qui reg D.lemp DL(0/15).lnmin DF(1/8).lnmin i.quarterly#i.censusreg S4.lpopall S4.share1559 S4.lrgspcap , robust cluster(state)
estimates store col3

qui lincomest D.lnmin + DL.lnmin + DL2.lnmin + DL3.lnmin + DL4.lnmin + DL5.lnmin + DL6.lnmin + DL7.lnmin + DL8.lnmin + ///
DL9.lnmin + DL10.lnmin + DL11.lnmin + DL12.lnmin + DL13.lnmin + DL14.lnmin + DL15.lnmin
estimates store lincom3


qui reg D.lemp DL(0/15).lnmin DF(1/8).lnmin i.quarterly#i.censusreg S4.lpopall S4.share1559 S4.lrgspcap , robust cluster(state)
qui lincomest DF.lnmin + DF2.lnmin + DF3.lnmin + DF4.lnmin + DF5.lnmin + DF6.lnmin + DF7.lnmin + DF8.lnmin
estimates store lincom3_2

qui reg D.lemp DL(0/15).lnmin i.quarterly#i.censusdiv S4.lpopall S4.share1559 S4.lrgspcap , robust cluster(state)
estimates store col4

qui lincomest D.lnmin + DL.lnmin + DL2.lnmin + DL3.lnmin + DL4.lnmin + DL5.lnmin + DL6.lnmin + DL7.lnmin + DL8.lnmin + ///
DL9.lnmin + DL10.lnmin + DL11.lnmin + DL12.lnmin + DL13.lnmin + DL14.lnmin + DL15.lnmin
estimates store lincom4

qui reg D.lemp DL(0/15).lnmin i.quarterly#i.censusreg S4.lpopall S4.share1559 S4.lrgspcap if indexedwage == 0 , robust cluster(state)
estimates store col5

qui lincomest D.lnmin + DL.lnmin + DL2.lnmin + DL3.lnmin + DL4.lnmin + DL5.lnmin + DL6.lnmin + DL7.lnmin + DL8.lnmin + ///
DL9.lnmin + DL10.lnmin + DL11.lnmin + DL12.lnmin + DL13.lnmin + DL14.lnmin + DL15.lnmin
estimates store lincom5

qui reg D.lemp DL(0/15).lnmin i.quarterly#i.censusreg S4.lpopall S4.share1559 S4.lrgspcap if year < 2008 , robust cluster(state)
estimates store col6

qui lincomest D.lnmin + DL.lnmin + DL2.lnmin + DL3.lnmin + DL4.lnmin + DL5.lnmin + DL6.lnmin + DL7.lnmin + DL8.lnmin + ///
DL9.lnmin + DL10.lnmin + DL11.lnmin + DL12.lnmin + DL13.lnmin + DL14.lnmin + DL15.lnmin
estimates store lincom6

#delimit ;
esttab lincom1 lincom2 lincom3 lincom4 lincom5 lincom6 using "$savedir/tables/table_dlfd_QCEW_QWI.tex", replace fragment
b(4) se(4) label star(* 0.1 ** 0.05 *** 0.01) nonotes nogaps nomtitles
coeflabels((1) "\textbf{Panel A: QCEW} \\ Current + Lags" )
;
esttab lincom2_2 lincom3_2 using "$savedir/tables/table_dlfd_QCEW_QWI.tex", append fragment
b(4) se(4) star(* 0.1 ** 0.05 *** 0.01) extracols(1)
nonotes nogap nomtitles nonum coeflabels((1) "Leads") 
;
#delimit cr

* QWI

use qwi , clear
keep if industry == 10 & agegrp == 0 // All ages in all industries in all sectors and ownership

sort state quarterly
xtset state quarterly
fvset base 1 state // Setting some technical factor-variable settings
fvset base 1 quarterly // Setting some technical factor-variable settings

estimates clear

qui reg D.lemp DL(0/15).lnmin i.quarterly#i.censusreg S4.lpopall S4.share1559 S4.lrgspcap , robust cluster(state)
estimates store col1

qui lincomest D.lnmin + DL.lnmin + DL2.lnmin + DL3.lnmin + DL4.lnmin + DL5.lnmin + DL6.lnmin + DL7.lnmin + DL8.lnmin + ///
DL9.lnmin + DL10.lnmin + DL11.lnmin + DL12.lnmin + DL13.lnmin + DL14.lnmin + DL15.lnmin
estimates store lincom1

qui reg D.lemp DL(0/15).lnmin DF(1/4).lnmin i.quarterly#i.censusreg S4.lpopall S4.share1559 S4.lrgspcap , robust cluster(state)
estimates store col2

qui lincomest D.lnmin + DL.lnmin + DL2.lnmin + DL3.lnmin + DL4.lnmin + DL5.lnmin + DL6.lnmin + DL7.lnmin + DL8.lnmin + ///
DL9.lnmin + DL10.lnmin + DL11.lnmin + DL12.lnmin + DL13.lnmin + DL14.lnmin + DL15.lnmin
estimates store lincom2

qui reg D.lemp DL(0/15).lnmin DF(1/4).lnmin i.quarterly#i.censusreg S4.lpopall S4.share1559 S4.lrgspcap , robust cluster(state)
qui lincomest DF.lnmin + DF2.lnmin + DF3.lnmin + DF4.lnmin
estimates store lincom2_2

qui reg D.lemp DL(0/15).lnmin DF(1/8).lnmin i.quarterly#i.censusreg S4.lpopall S4.share1559 S4.lrgspcap , robust cluster(state)
estimates store col3

qui lincomest D.lnmin + DL.lnmin + DL2.lnmin + DL3.lnmin + DL4.lnmin + DL5.lnmin + DL6.lnmin + DL7.lnmin + DL8.lnmin + ///
DL9.lnmin + DL10.lnmin + DL11.lnmin + DL12.lnmin + DL13.lnmin + DL14.lnmin + DL15.lnmin
estimates store lincom3


qui reg D.lemp DL(0/15).lnmin DF(1/8).lnmin i.quarterly#i.censusreg S4.lpopall S4.share1559 S4.lrgspcap , robust cluster(state)
qui lincomest DF.lnmin + DF2.lnmin + DF3.lnmin + DF4.lnmin + DF5.lnmin + DF6.lnmin + DF7.lnmin + DF8.lnmin
estimates store lincom3_2


qui reg D.lemp DL(0/15).lnmin i.quarterly#i.censusdiv S4.lpopall S4.share1559 S4.lrgspcap , robust cluster(state)
estimates store col4

qui lincomest D.lnmin + DL.lnmin + DL2.lnmin + DL3.lnmin + DL4.lnmin + DL5.lnmin + DL6.lnmin + DL7.lnmin + DL8.lnmin + ///
DL9.lnmin + DL10.lnmin + DL11.lnmin + DL12.lnmin + DL13.lnmin + DL14.lnmin + DL15.lnmin
estimates store lincom4

qui reg D.lemp DL(0/15).lnmin i.quarterly#i.censusreg S4.lpopall S4.share1559 S4.lrgspcap if indexedwage == 0 , robust cluster(state)
estimates store col5

qui lincomest D.lnmin + DL.lnmin + DL2.lnmin + DL3.lnmin + DL4.lnmin + DL5.lnmin + DL6.lnmin + DL7.lnmin + DL8.lnmin + ///
DL9.lnmin + DL10.lnmin + DL11.lnmin + DL12.lnmin + DL13.lnmin + DL14.lnmin + DL15.lnmin
estimates store lincom5

qui reg D.lemp DL(0/15).lnmin i.quarterly#i.censusreg S4.lpopall S4.share1559 S4.lrgspcap if year < 2008 , robust cluster(state)
estimates store col6

qui lincomest D.lnmin + DL.lnmin + DL2.lnmin + DL3.lnmin + DL4.lnmin + DL5.lnmin + DL6.lnmin + DL7.lnmin + DL8.lnmin + ///
DL9.lnmin + DL10.lnmin + DL11.lnmin + DL12.lnmin + DL13.lnmin + DL14.lnmin + DL15.lnmin
estimates store lincom6

#delimit ;
esttab lincom1 lincom2 lincom3 lincom4 lincom5 lincom6 using "$savedir/tables/table_dlfd_QCEW_QWI.tex", append fragment
b(4) se(4) label star(* 0.1 ** 0.05 *** 0.01) nonotes nogaps nomtitles nonum
coeflabels((1) "\textbf{Panel B: QWI} \\ Current + Lags" )
;
esttab lincom2_2 lincom3_2 using "$savedir/tables/table_dlfd_QCEW_QWI.tex", append fragment
b(4) se(4) star(* 0.1 ** 0.05 *** 0.01) extracols(1)
nonotes nogap nomtitles nonum coeflabels((1) "Leads") 
;
#delimit cr

clear all
